@@ -6,9 +6,13 @@
 #include <Rmath.h>
 
 #include "eval_nvmix_integral.h"
+#include "eval_densmix_integrand.h"
+#include "logsumexp2.h"
 
 static const R_CallMethodDef callMethods[] = {
-    {"eval_nvmix_integral", (DL_FUNC) &eval_nvmix_integral, 8},
+    {"eval_nvmix_integral", (DL_FUNC) &eval_nvmix_integral, 10},
+    {"eval_densmix_integrand", (DL_FUNC) &eval_densmix_integrand, 7},
+    {"logsumexp2", (DL_FUNC) &logsumexp2, 3},
     {NULL, NULL, 0}
 };
 
